<TS language="pt_BR" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Criar novo endereço</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copie o endereço selecionado para a área de transferência do sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Mostrar &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Assinar &amp;Mensagem</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar Mensagem</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Excluir os endereços selecionados da lista</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Livro de Endereços</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>E&amp;xcluir</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiar rótu&amp;lo</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exportar Dados do Livro de Endereços</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Erro ao exportar</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Não foi possível escrever no arquivo %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Rótulo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sem rótulo)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Janela da Frase de Segurança</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Digite a frase de segurança</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova frase de segurança</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repita a nova frase de segurança</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Serve para desativar o envio de dinheiro trivial quando conta do SO for comprometida. Não oferece segurança real.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Apenas para participação</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Insira a nova senha para a carteira.&lt;br/&gt;Favor usar uma senha com &lt;b&gt;dez ou mais caracteres aleatórios&lt;/b&gt;, ou &lt;b&gt;oito ou mais palavras&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Criptografar carteira</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operação precisa da sua senha para desbloquear a carteira.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear carteira</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Alterar senha</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Digite a frase de segurança antiga e nova para a carteira.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmar criptografia da carteira</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Aviso: Se você criptografar sua carteira e perder sua senha, você vai &lt;b&gt;PERDER TODAS AS SUAS MOEDAS&lt;/ b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Tem certeza que deseja criptografar a carteira?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Carteira criptografada</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Qualquer backup prévio que você tenha feito da sua carteira deve ser substituído pelo novo e encriptado arquivo gerado. Por razões de segurança, qualquer backup do arquivo não criptografado se tornará inútil assim que você começar a usar uma nova carteira criptografada.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Falha ao criptografar carteira</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Falha na criptografia devido a um erro inerno. Sua carteira não foi criptografada.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>As senhas não conferem.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Falha ao desbloquear carteira</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>A senha inserida para descriptografar a carteira está incorreta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>A senha da carteira foi alterada com êxito.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Aviso: Tecla Caps Lock ativa!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Carteira</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Visão geral</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar visão geral da carteira</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Receber</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Mostrar a lista de endereços para o recebimento de pagamentos</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Navegar pelo histórico de transações</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Edite a lista de endereços armazenados e rótulos</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;air</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opções...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Exibir / Ocultar</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Criptografar Carteira...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Mudar frase de segurança...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Mudar a frase de segurança utilizada na criptografia da carteira</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear carteira</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Bloquear Carteira</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Bloquear Carteira</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Assinar &amp;mensagem...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensagem...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Exportar...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar os dados da guia atual para um arquivo</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Janela de &amp;depuração</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir console de depuração e diagnóstico</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Definições</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Atualizado</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Recuperando o atraso ...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transação enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transação recebida</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Carteira está &lt;b&gt;criptografada&lt;/b&gt; e atualmente &lt;b&gt;bloqueada&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerta da Rede</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantia:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Taxa:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Rendimento baixo:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Depois da taxa:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>trocar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantidade</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmações</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar endereço</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar rótulo</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar quantia</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID da transação</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar quantia</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar taxa</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar pós taxa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia saída de pouco valor</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar troco</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>sim</translation>
    </message>
    <message>
        <source>no</source>
        <translation>não</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sem rótulo)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>troco de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(troco)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar Endereço</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Rótulo</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Endereço</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Novo endereço de recebimento</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Novo endereço de envio</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar endereço de recebimento</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar endereço de envio</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>O endereço digitado "%1" já se encontra no catálogo de endereços.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Não foi possível desbloquear a carteira</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Falha ao gerar chave</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapear porta usando &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Porta:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Porta do serviço de proxy (ex. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimizar em vez de sair do aplicativo quando a janela for fechada. Quando esta opção é escolhida, o aplicativo só será fechado selecionando Sair no menu Arquivo.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>Mostrar en&amp;dereços na lista de transações</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Mostrar apenas um ícone na bandeja ao minimizar a janela.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizar para a bandeja em vez da barra de tarefas.</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizar ao sair</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Mostrar</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Linguagem da interface:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unidade usada para mostrar quantidades:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Escolha a unidade padrão de subdivisão para interface mostrar quando enviar bitcoins.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>default</source>
        <translation>padrão</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>O endereço proxy fornecido é inválido.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponível:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Seu saldo atual spendable</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Imaturo:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Seu saldo total atual</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versão do cliente</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informação</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Horário de inicialização</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Número de conexões</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Corrente de blocos</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Quantidade atual de blocos</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Horário do último bloco</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Tráfico de Rede</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totais</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Entrada:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Saída:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Arquivo de log de depuração</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Limpar console</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Total estimado de blocos</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nome do cliente</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Use as setas para cima e para baixo para navegar pelo histórico, e &lt;b&gt;Ctrl-L&lt;/b&gt; para limpar a tela.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Digite &lt;b&gt;help&lt;/b&gt; para uma visão geral dos comandos disponíveis.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar moedas</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entradas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaticamente selecionado</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Saldo insuficiente!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantia:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Taxa:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Rendimento baixo:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Depois da taxa:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar para vários destinatários de uma só vez</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Adicionar destinatário</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpar Tudo</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar o envio</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar quantia</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar quantia</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar taxa</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar pós taxa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia saída de pouco valor</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar troco</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirme o envio de moedas</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>O endereço do destinatário não é válido, favor verificar.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>A quantia à pagar deve ser maior que 0</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>A quantia excede o seu saldo</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>O total excede o seu saldo quando a taxa da transação %1 é incluída</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Endereço duplicado: pode-se enviar para cada endereço apenas uma vez por transação.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sem rótulo)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Q&amp;uantidade:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pagar &amp;Para:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensagem:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Rótulo:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Colar o endereço da área de transferência</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Digite um rótulo para este endereço para adicioná-lo ao catálogo de endereços</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Assinaturas - Assinar / Verificar uma mensagem</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Assinar mensagem</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Você pode assinar mensagens com seus endereços para provar que você é o dono deles. Seja cuidadoso para não assinar algo vago, pois ataques de pishing podem tentar te enganar para dar sua assinatura de identidade para eles. Apenas assine afirmações completamente detalhadas com as quais você concorda.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Colar o endereço da área de transferência</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Entre a mensagem que você quer assinar aqui</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiar a assinatura para a área de transferência do sistema</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Assinar &amp;mensagem</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Limpar todos os campos de assinatura da mensagem</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpar Tudo</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar mensagem</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Forneça o endereço da assinatura, a mensagem (se assegure que você copiou quebras de linha, espaços, tabs, etc. exatamente) e a assinatura abaixo para verificar a mensagem. Cuidado para não ler mais na assinatura do que está escrito na mensagem propriamente, para evitar ser vítima de uma ataque do tipo "man-in-the-middle".</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Limpar todos os campos de assinatura da mensagem</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Clique em "Assinar mensagem" para gerar a assinatura</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>O endereço digitado é inválido</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Favor checar o endereço e tente novamente</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>O endereço fornecido não se refere a uma chave.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>O desbloqueio da carteira foi cancelado</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>A chave privada do endereço inserido não está disponível</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Falha ao assinar mensagem</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mensagem assinada</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>A assinatura não pode ser descodificada</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Favor checar a assinatura e tente novamente</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>A assinatura não corresponde a mensagem</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Falha na verificação da mensagem</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mensagem verificada</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aberto até %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>em conflito</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/não confirmado</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmações</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ainda não foi propagada na rede com êxito.</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconhecido</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Para</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>próprio endereço</translation>
    </message>
    <message>
        <source>label</source>
        <translation>rótulo</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crédito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>não aceito</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Débito</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Taxa da transação</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Valor líquido</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensagem</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantia</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadeiro</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalhes da transação</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Este painel mostra uma descrição detalhada da transação</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantidade</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aberto até %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Não confirmado</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmado (%1 confirmações)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Conflitado</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Gerado mas não aceito</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recebido</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Recebido</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado para</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagamento para você mesmo</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status da transação. Passe o mouse sobre este campo para mostrar o número de confirmações.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data e hora em que a transação foi recebida.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transação</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Endereço de destino da transação.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Quantidade debitada ou creditada ao saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Essa semana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Esse mês</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Último mês</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Este ano</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervalo...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recebido</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado para</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Para você mesmo</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minerado</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Quantia mínima</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar endereço</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar rótulo</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar quantia</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID da transação</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar rótulo</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostrar detalhes da transação</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Rótulo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantidade</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervalo: </translation>
    </message>
    <message>
        <source>to</source>
        <translation>para</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Um erro ocorreu ao configurar a porta RPC %u para escuta em IPv6, voltando ao IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Um erro ocorreu ao configurar a porta RPC %u para escuta em IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uso:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lista de comandos</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Obtenha ajuda sobre um comando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Cuidado: valor de -paytxfee escolhido é muito alto! Este é o valor da taxa de transação que você irá pagar se enviar a transação.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Aviso: wallet.dat corrompido, dados recuperados! Arquivo wallet.dat original salvo como wallet.{timestamp}.bak em %s; se seu saldo ou transações estiverem incorretos, você deve restauras o backup.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Cuidado: erro ao ler arquivo wallet.dat! Todas as chaves foram lidas corretamente, mas dados transações e do catálogo de endereços podem estar faltando ou estar incorretas.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Falha ao escutar em qualquer porta. Use -listen=0 se você quiser isso.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Para usar a opção %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Você precisa especificar rpcpassword=&lt;senha&gt; no arquivo de configurações:?
%s?
Se o arquivo não existir, crie um com permissão de leitura apenas pelo dono</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Quantidade inválida para -paytxfee=&lt;quantidade&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrompido, recuperação falhou</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Endereço -proxy inválido: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Impossível encontrar o endereço -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Impossível encontrar endereço -externalip: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Erro ao carregar wallet.dat: Carteira corrompida</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Erro ao carregar wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Carregando endereços...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Impossível vincular a %s neste computador (bind retornou erro %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Quantidade inválida</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Rede desconhecida especificada em -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Saldo insuficiente</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Carregando índice de blocos...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Carregando carteira...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Não foi possível escrever no endereço padrão</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Re-escaneando...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Carregamento terminado!</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
</TS>